package cz.muni.fi.pb162.arrays;

import java.util.Arrays;

/**
 * Pole je skupina premennych rovnakého typu, na ktoré odkazuje jedná premenná
 * Veľkosť poľa je pevne daná a nie je možné ju meniť
 * Na deklaraciu nového poľa, definujeme typ s hranatými zátvorkami (napr. String[])
 * Môžeme vytvoriť pole primitívneho aj objektového typu
 *
 * V metóde main nájdete ukážky deklarácie a základné operácie s poliami
 */
public class Demo {
    public static void main(String[] args) {
        // veľkosť poľa je možné určiť vymenovaním prvkov
        String[] textNumbers = {"One", "Two", "Three", "Four", "Five"};

        // alebo vytvorením nového poľa a zvolením jeho veľkosti
        // jednotlivé premenné naberú defaultnú hodnotu
        int[] numbers = new int[5]; // = {0, 0, 0, 0, 0}

        // na jednotlivé pozície pristupujeme následovne
        numbers[2] = 3;

        // veľkosť poľa získame pomocou atribútu length
        System.out.println("Veľkosť poľa numbers je: " + numbers.length);

        // operátor "=" vytvára len kópiu odkazu
        String[] linkCopy = textNumbers;

        // premenné "textNumbers" a "numbers" odkazuju na to isté pole
        textNumbers[0] = "Uno";
        System.out.println("linkCopy[0] = " + linkCopy[0]); // Uno

        Car[] cars = {new Car("Porsche"), new Car("Audi")};
        // Ak chceme vytvorit kópiu poľa využijeme metódu "copyOf" z knižnice Arrays
        // metóda vytvorí nové pole a skopíruje odkazy na objekty z pôvodného poľa
        Car[] carsCopy = Arrays.copyOf(cars, 2);

        // zmena v poli sa neprejaví v druhom poli
        carsCopy[0] = new Car("BMW");
        System.out.println("Nahradenie objektu v poli carsCopy");
        System.out.println("cars[0] = " + cars[0]); // Porsche
        System.out.println("carsCopy[0] = " + carsCopy[0]); // BMW

        // ak zmeníme atribút objektu z pôvodného poľa zmena sa prejaví v oboch
        cars[1].setName("Mercedes");
        System.out.println("Zmena atribútu v objekte Car na ktoré odkazujú obe polia");
        System.out.println("cars[1] = " + cars[1]); // Mercedes
        System.out.println("carsCopy[1] = " + carsCopy[1]); // Mercedes
    }
}
